#
# This file is part of Test-File-Content
#
# This software is Copyright (c) 2011 by Moritz Onken.
#
# This is free software, licensed under:
#
#   The (three-clause) BSD License
#
__PACKAGE__->make_immutable;